@@ -506,8 +506,6 @@ class Distributive():
         try:
             if path.lexists(path.join(directory, 'lib64')):
                 d['os_arch_machine'] = 'x86_64'
-            elif path.lexists(path.join(directory, 'lib')):
-                d['os_arch_machine'] = 'i686'
             else:
                 d['os_arch_machine'] = ''
             dv = LinuxDataVars(systemRoot=directory)
