@@ -226,14 +226,17 @@ class Install(MethodsInterface):
             raise DistributiveError(
                 _("Failed to write the master boot record\n%s") %
                 dd_process.read())
-        target.close()
-        # выполнить установку syslinux загрузчика
         install_root_dev = self.clVars.Get('os_install_root_dev')
-        syslinux_process = process("/usr/bin/syslinux",
-                                   install_root_dev, stderr=STDOUT)
+        mount_path = target.convertToDirectory()
+        syslinux_process = process("/usr/bin/extlinux", '--install',
+                                   mount_path.directory, stderr=STDOUT)
         if syslinux_process.failed():
             raise DistributiveError(_("Failed to install syslinux\n%s") %
                                     syslinux_process.read())
+        target.close()
+        # выполнить установку syslinux загрузчика
+
+
         # установить загрузочный раздел активным
         return self.setActivePartition(self.clVars.Get('os_install_root_dev'))
 
