@@ -44,7 +44,7 @@ setLocalTranslate('cl_install3', sys.modules[__name__])
 class DistroRepository(Linux):
     contentCache = {}
 
-    marches = ['i686', 'x86_64']
+    marches = ['x86_64']
 
     extensiton = ['iso', 'tar.bz2', 'tar.gz', 'tar.7z', 'tar.lzma']
 
@@ -391,7 +391,7 @@ class VariableClImageArchMachine(DistroRepository, Variable):
     type = 'choice'
     opt = ['--march']
     metavalue = "ARCH"
-    available_arch = ["i686", "x86_64"]
+    available_arch = ["x86_64"]
 
     def init(self):
         self.label = "%s %s" % (_("Filter"), _("by processor architecture"))
